@@ -6,7 +6,10 @@
 #                      \___/_/\_\ .__/ \__,_|\__|
 #                               |_| XML parser
 #
-# Copyright (c) 2017 Expat development team
+# Copyright (c) 2017-2021 Sebastian Pipping <sebastian@pipping.org>
+# Copyright (c) 2017      Rolf Eike Beer <eike@sf-mail.de>
+# Copyright (c) 2019      Mohammed Khajapasha <mohammed.khajapasha@intel.com>
+# Copyright (c) 2019      Philippe Antoine <contact@catenacyber.fr>
 # Licensed under the MIT license:
 #
 # Permission is  hereby granted,  free of charge,  to any  person obtaining
@@ -36,7 +39,7 @@ if [[ ${TRAVIS_OS_NAME} = osx ]]; then
     export PATH="/usr/local/opt/coreutils/libexec/gnubin${PATH:+:}${PATH}"
     export PATH="/usr/local/opt/findutils/libexec/gnubin${PATH:+:}${PATH}"
 elif [[ ${TRAVIS_OS_NAME} = linux ]]; then
-    export PATH="/usr/lib/llvm-9/bin:${PATH}"
+    export PATH="/usr/lib/llvm-13/bin:${PATH}"
 fi
 
 echo "New \${PATH}:"
@@ -56,23 +59,9 @@ elif [[ ${MODE} = cmake-oos ]]; then
     mkdir build
     cd build
     cmake ${CMAKE_ARGS} ..
-    make VERBOSE=1 all test
+    make VERBOSE=1 CTEST_OUTPUT_ON_FAILURE=1 all test
     make DESTDIR="${PWD}"/ROOT install
     find ROOT -printf "%P\n" | sort
-elif [[ ${MODE} = cppcheck ]]; then
-    cppcheck --version
-    find_args=(
-        -type f \(
-            -name \*.cpp
-            -o -name \*.c
-        \)
-        -not \(  # Exclude .c files that are merely included by other files
-            -name xmltok_ns.c
-            -o -name xmltok_impl.c
-        \)
-        -exec cppcheck --quiet --error-exitcode=1 --force {} +
-    )
-    find "${find_args[@]}"
 elif [[ ${MODE} = clang-format ]]; then
     ./apply-clang-format.sh
     git diff --exit-code
